import { LocalStorage } from 'quasar';
import { boot } from 'quasar/wrappers';
import { useMainStore, pinia } from '@flaschengeist/api';

function isCordova() {
  return window.hasOwnProperty('cordova');
}

function error() {
  console.debug('NativeStorage Error');
}

export default boot(({ app }) => {
  app.use(pinia);

  document.addEventListener('deviceready', () => {
    const store = useMainStore();

    // Load main state from storage
    if (isCordova()) {
      // is cordova, so use Native Storage
      window.NativeStorage.keys((keys) => {
        // Check if key is set
        if (keys.includes('main_store'))
          window.NativeStorage.getItem<typeof store.$state>(
            'main_store',
            (v) => {
              // Check is object, then patch it
              if (typeof v === 'object') store.$patch(v);
            },
            error
          );
      }, error);
    } else {
      // is not cordova, so use LocalStorage
      store.$patch(LocalStorage.getItem<typeof store.$state>('main_store') || {});
    }

    // Subscript to save changes of state to storage
    store.$subscribe(
      (mutation, state) => {
        if (isCordova()) window.NativeStorage.setItem('main_store', state, () => undefined, error);
        else LocalStorage.set('main_store', state);
      },
      { deep: true }
    );

    void store.init();
  });
});
