/**
 * @name Native Storage
 * @premier nativestorage
 * @description Native storage of variables in Android and iOS
 *
 * @usage
 * ```typescript
 * import { NativeStorage } from '@ionic-native/native-storage/ngx';
 *
 * constructor(private nativeStorage: NativeStorage) { }
 *
 * ...
 *
 * this.nativeStorage.setItem('myitem', {property: 'value', anotherProperty: 'anotherValue'})
 *   .then(
 *     () => console.log('Stored item!'),
 *     error => console.error('Error storing item', error)
 *   );
 *
 * this.nativeStorage.getItem('myitem')
 *   .then(
 *     data => console.log(data),
 *     error => console.error(error)
 *   );
 * ```
 */
export {};

declare class NativeStorageOriginal {
  /**
   * Initialises shared storage with the suite name when using app groups in iOS
   * @param reference {string}
   */
  initWithSuiteName(reference: string, success: () => void, error: () => void): void;
  /**
   * Stores a value
   * @param reference {string}
   * @param value
   */
  setItem(reference: string, value: unknown, success: () => void, error: () => void): void;
  /**
   * Gets a stored item
   * @param reference {string}
   */
  getItem<T = unknown>(reference: string, success: (obj: T) => void, error: () => void): void;
  /**
   * Retrieving all keys
   */
  keys(success: (keys: string[]) => void, error: () => void): void;
  /**
   * Removes a single stored item
   * @param reference {string}
   */
  remove(reference: string, success: () => void, error: () => void): void;
  /**
   * Removes all stored values.
   */
  clear(success: () => void, error: () => void): void;
}

declare const NativeStorage: NativeStorageOriginal;

declare global {
  interface Window {
    NativeStorage: NativeStorageOriginal;
  }
}
